@@ -4,9 +4,11 @@ from __future__ import annotations
 
 import os
 import platform
+import stat
 import subprocess
 import sys
-from collections.abc import Iterable, Mapping, Sequence
+import warnings
+from collections.abc import Callable, Iterable, Mapping, Sequence
 from contextlib import suppress
 from contextvars import ContextVar
 from dataclasses import field, replace
@@ -19,8 +21,8 @@ from tempfile import TemporaryDirectory
 from types import TracebackType
 from typing import (
     Any,
-    Callable,
     Literal,
+    ParamSpec,
     TypeVar,
     get_args,
     overload,
@@ -56,7 +58,6 @@ from ._types import (
     JSONSerializable,
     LazyDict,
     Operation,
-    ParamSpec,
     Phase,
     RelativePath,
     StrOrPath,
@@ -573,7 +574,7 @@ class Worker:
                     del self.answers.last[var_name]
                 # Skip immediately to the next question when it has no default
                 # value.
-                if question.default is MISSING:
+                if question.get_default() is MISSING:
                     continue
             if var_name in self.answers.init:
                 # Try to parse and validate (if the question has a validator)
@@ -733,7 +734,7 @@ class Worker:
                 else:
                     self._render_file(src_relpath, dst_relpath, extra_context=ctx or {})
 
-    def _render_file(
+    def _render_file(  # noqa: C901
         self,
         src_relpath: Path,
         dst_relpath: Path,
@@ -785,7 +786,17 @@ class Worker:
                 # replace a symlink with a file we have to unlink it first
                 dst_abspath.unlink()
             dst_abspath.write_bytes(new_content)
-            dst_abspath.chmod(src_mode)
+            if (dst_mode := dst_abspath.stat().st_mode) != src_mode:
+                try:
+                    dst_abspath.chmod(src_mode)
+                except PermissionError:
+                    # In some filesystems (e.g., gcsfuse), `chmod` is not allowed,
+                    # so we suppress the `PermissionError` here.
+                    warnings.warn(
+                        f"Path permissions for {dst_abspath} cannot be changed from "
+                        f"{stat.filemode(dst_mode)} to {stat.filemode(src_mode)}",
+                        stacklevel=2,
+                    )
 
     def _render_symlink(self, src_relpath: Path, dst_relpath: Path) -> None:
         """Render one symlink.
